@@ -1,5 +1,6 @@
 from importlib import metadata
 
+from ._base_notifier import BaseNotifier
 from ._utils import check_parens
 from .decorators import (
     call_counter,
@@ -8,8 +9,10 @@ from .decorators import (
     chime_on_end,
     log,
     memory_limit,
+    multi_shape_tracker,
     notify_on_end,
     retry,
+    shape_tracker,
     timeout,
     timer,
 )
@@ -19,6 +22,7 @@ __version__ = metadata.version(__title__)
 
 __all__ = (
     "check_parens",
+    "BaseNotifier",
     "call_counter",
     "catch",
     "check_args",
@@ -27,6 +31,8 @@ __all__ = (
     "timer",
     "memory_limit",
     "notify_on_end",
+    "shape_tracker",
+    "multi_shape_tracker",
     "retry",
     "timeout",
 )
